# Tasks

This section contains the API reference for the distilabel tasks. For an example on how to create and use a task, see the [Tutorial - Tasks](../../../sections/learn/tasks/index.md).

::: distilabel.steps.tasks.base

## General Text Generation

::: distilabel.steps.tasks.text_generation

## Evol Instruct

::: distilabel.steps.tasks.evol_instruct.base
::: distilabel.steps.tasks.evol_instruct.generator
::: distilabel.steps.tasks.evol_instruct.utils

### Evol Complexity

::: distilabel.steps.tasks.evol_instruct.evol_complexity.base
::: distilabel.steps.tasks.evol_instruct.evol_complexity.generator
::: distilabel.steps.tasks.evol_instruct.evol_complexity.utils

## Evol Quality

::: distilabel.steps.tasks.evol_quality.base
::: distilabel.steps.tasks.evol_quality.utils

## DEITA Scorers

::: distilabel.steps.tasks.complexity_scorer
::: distilabel.steps.tasks.quality_scorer
